#
# spec file for package falcoctl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           falcoctl
Version:        0.11.0
Release:        1.1
Summary:        CLI / Administrative tooling for Falco
License:        Apache-2.0
URL:            https://github.com/falcosecurity/falcoctl
Source:         falcoctl-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23.4
BuildRequires:  zsh

%description
The official CLI tool for working with [Falco](https://github.com/falcosecurity/falco) and its ecosystem components.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="\
    -X github.com/falcosecurity/falcoctl/cmd/version.semVersion=%{version} \
    -X github.com/falcosecurity/falcoctl/cmd/version.gitCommit=v%{version} \
    -X github.com/falcosecurity/falcoctl/cmd/version.buildDate=${BUILD_DATE}" \
   -o bin/falcoctl .

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Mon Jan 27 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.11.0:
  * fix(follow): file handling of artifacts with directories
  * chore(deps): Bump the actions group with 2 updates
  * chore(deps): Bump the gomod group with 2 updates
  * chore(deps): Bump the gomod group with 5 updates
  * chore(deps): Bump the actions group with 5 updates
  * chore(deps): Bump the gomod group across 1 directory with 5
    updates
  * chore(deps): Bump cloud.google.com/go/storage from 1.49.0 to
    1.50.0
  * chore(deps): Bump golang.org/x/net from 0.33.0 to 0.34.0
  * chore(deps): Bump k8s.io/client-go from 0.31.3 to 0.32.0
  * chore(deps): Bump k8s.io/apimachinery from 0.31.3 to 0.32.0
  * chore(go.mod): bump go version to 1.23.4
  * chore(deps): Bump golang.org/x/oauth2 from 0.24.0 to 0.25.0
  * chore(deps): Bump golang.org/x/term from 0.27.0 to 0.28.0
  * chore(deps): Bump golang.org/x/sys from 0.28.0 to 0.29.0
  * chore(deps): Bump github.com/onsi/ginkgo/v2 in the gomod group
  * chore(deps): Bump github.com/onsi/gomega in the gomod group
  * chore(deps): Bump cloud.google.com/go/storage from 1.48.0 to
    1.49.0
  * chore(deps): Bump github.com/distribution/distribution/v3
  * chore(deps): Bump github.com/cilium/ebpf from 0.16.0 to 0.17.1
  * chore(deps): Bump the gomod group with 2 updates
  * chore(deps): Bump golang.org/x/net from 0.32.0 to 0.33.0
  * chore(deps): Bump github.com/docker/cli
  * chore(deps): Bump google.golang.org/api from 0.210.0 to 0.211.0
  * chore(deps): Bump github.com/docker/docker
  * chore(deps): Bump actions/setup-go in the actions group
  * chore(deps): Bump the gomod group with 6 updates
  * chore(deps): Bump golang.org/x/crypto from 0.30.0 to 0.31.0
  * update(linter): remove deprecated linters
  * update(ci/linter): bump golangci-lint to v1.62.2
  * update(makefile): bump golangci-lint to v1.62.2
  * fix(mediaType): do not omit the original media type if not a
    well-known media type
  * chore(deps): Bump github.com/falcosecurity/driverkit in the
    gomod group
  * chore(deps): Bump golang.org/x/net from 0.31.0 to 0.32.0
  * chore(deps): Bump golang.org/x/term from 0.26.0 to 0.27.0
  * chore(deps): Bump cloud.google.com/go/storage from 1.47.0 to
    1.48.0
  * chore(deps): Bump golang.org/x/sys from 0.27.0 to 0.28.0
  * chore(deps): Bump docker/build-push-action in the actions group
  * chore(deps): Bump github.com/pterm/pterm in the gomod group
  * chore(deps): Bump github.com/onsi/gomega from 1.35.1 to 1.36.0
  * chore(deps): Bump docker/metadata-action in the actions group
  * chore(deps): Bump github.com/stretchr/testify from 1.9.0 to
    1.10.0
  * chore(deps): Bump github.com/onsi/ginkgo/v2 from 2.21.0 to
    2.22.0
  * chore(deps): Bump google.golang.org/api from 0.206.0 to 0.209.0
  * chore(deps): Bump the gomod group with 3 updates
  * fix(auth/gcp): ensure correct OAuth scope for Artifact Registry
    with service account
* Thu Nov 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.10.1:
  * update(go): bumped driverkit dep to v0.20.4.
  * fix(pkg/oci): fix Tags pagination support.
  * chore(deps): Bump cloud.google.com/go/storage from 1.46.0 to
    1.47.0
  * chore(deps): Bump google.golang.org/api from 0.205.0 to 0.206.0
  * chore(deps): Bump github.com/golang-jwt/jwt/v4 from 4.5.0 to
    4.5.1
  * chore(deps): Bump golang.org/x/oauth2 from 0.23.0 to 0.24.0
  * chore(deps): Bump github.com/distribution/distribution/v3
  * chore(deps): Bump golang.org/x/net from 0.30.0 to 0.31.0
  * chore(deps): Bump golang.org/x/term from 0.25.0 to 0.26.0
  * chore(deps): Bump google.golang.org/api from 0.204.0 to 0.205.0
  * chore(deps): Bump goreleaser/goreleaser-action in the actions
    group
  * chore(deps): Bump github.com/onsi/ginkgo/v2 from 2.20.2 to
    2.21.0
  * chore(deps): Bump google.golang.org/api from 0.200.0 to 0.204.0
  * chore(deps): Bump cloud.google.com/go/storage from 1.45.0 to
    1.46.0
  * chore(deps): Bump github.com/onsi/gomega from 1.34.2 to 1.35.1
  * chore(deps): Bump k8s.io/client-go from 0.30.2 to 0.31.2
  * chore(deps): Bump github.com/sigstore/cosign/v2 from 2.2.4 to
    2.4.1
  * chore(deps): Bump github.com/onsi/ginkgo/v2 from 2.19.0 to
    2.20.2
  * chore(deps): Bump github.com/docker/docker
  * chore(deps): Bump k8s.io/apimachinery from 0.30.2 to 0.31.2
  * chore(deps): Bump cloud.google.com/go/storage from 1.43.0 to
    1.45.0
  * chore(deps): Bump github.com/onsi/gomega from 1.33.1 to 1.34.2
  * chore(deps): Bump github.com/docker/cli
  * chore(deps): Bump the actions group with 2 updates
  * chore(deps): Bump github.com/cilium/ebpf from 0.15.0 to 0.16.0
  * chore(deps): Bump github.com/distribution/distribution/v3
  * chore(deps): align go.opentelemetry.io/otel/sdk/metric with
    otel/sdk v1.29.0
  * update go to 1.22.8
  * chore(deps): Bump the gomod group across 1 directory with 11
    updates
  * chore(deps): Bump the actions group with 2 updates
  * fix(cmd): relax file perms for Falco driver config override
  * chore(deps): Bump the actions group with 4 updates
  * chore(deps): Bump the actions group with 2 updates
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.10.0:
  * fix(goreleaser): use latest tag when two tags point to the same
    commit
  * update(go,pkg): updated driverkit to v0.20.3.
  * update(driver/config): add new unit tests
  * update(driver/config)!: use the same logic to configure engine
    kind for different enviroments
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.9.1:
  * chore(deps): Bump actions/upload-artifact in the actions group
  * fix(auth/basic): bind pflags to viper only when required
  * chore(deps): Bump the actions group across 1 directory with 3
    updates
  * chore(deps): Bump the actions group with 3 updates
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.9.0:
  * update(OWNERS): remove new line
  * update(OWNERS): add loresuso to approvers
  * chore(deps): Bump github.com/docker/docker
  * chore(pkg): bump driverkit to 0.20.0
  * chore(deps): Bump the actions group with 4 updates
  * chore(deps): Bump goreleaser/goreleaser-action from 5.1.0 to
    6.0.0
  * update(.goreleaser): bump version to v2
  * chore(deps): Bump slsa-framework/slsa-verifier in the actions
    group
  * chore(deps): Bump docker/build-push-action from 5.4.0 to 6.4.1
  * fix(push): use basename for artifacts when compressed in tar.gz
  * chore(Makefile): add .PHONY to falcoctl target
  * Add support for S3 index storage backend
  * fix: allow login to express registry as ref but actually
    extract the registry
  * chore(deps): Bump github.com/docker/cli
  * chore(deps): Bump the actions group across 1 directory with 4
    updates
  * chore(deps): Bump google.golang.org/grpc from 1.64.0 to 1.64.1
  * feat(dockerfile): use distroless image for falcoctl docker
    image
  * chore(go.mod): bump go version to 1.22.5
  * chore(cmd/driver,pkg/driver): allow to disable kernel headers
    automatic download.
  * chore(deps): Bump google.golang.org/api from 0.185.0 to 0.186.0
  * chore(deps): Bump github.com/hashicorp/go-retryablehttp
  * chore(deps): Bump google.golang.org/api from 0.184.0 to 0.185.0
  * chore(deps): Bump
    github.com/Azure/azure-sdk-for-go/sdk/azidentity
  * feat(auth/basic): extend auth basic command
  * chore(deps): Bump the actions group with 2 updates
  * chore(deps): Bump the gomod group with 4 updates
  * chore(deps): Bump cloud.google.com/go/storage from 1.41.0 to
    1.42.0
  * chore(deps): Bump google.golang.org/api from 0.183.0 to 0.184.0
  * chore(deps): Bump the gomod group with 2 updates
  * chore(deps): Bump golang.org/x/net from 0.25.0 to 0.26.0
  * chore(deps): Bump golang.org/x/term from 0.20.0 to 0.21.0
  * chore(deps): Bump google.golang.org/api from 0.182.0 to 0.183.0
  * chore(deps): Bump golang.org/x/sys from 0.20.0 to 0.21.0
  * chore(deps): Bump the gomod group with 5 updates
  * chore(deps): Bump docker/login-action in the actions group
  * chore(deps): Bump google.golang.org/api from 0.181.0 to 0.182.0
  * chore(deps): Bump github.com/spf13/viper from 1.18.2 to 1.19.0
  * chore(deps): Bump github.com/onsi/ginkgo/v2 from 2.17.3 to
    2.19.0
* Sat Jun  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.8.0:
  * add dependabot config and update golangci-lint by @cpanato in
    [#385]
  * chore(cmd): fixed up some strings. by @FedeDP in #407
  * fix: fixed go.sum entry to fix build. by @FedeDP in #415
  * feat: adding support for KMS in cosign by @brennoo in #416
  * fix: Dead link in PR template by @krnowak in #424
  * pkg/driver/flatcar: Update the script by @krnowak in #425
  * fix(pkg/driver): fixed generic kernelversion fixup method. by
    @FedeDP in #427
  * new(cmd/driver): support user provided headers option for
    driver download by @toamto94 in #428
  * fix(pusher): correctly report artifact type by @alacuku in #442
  * Remove extra '$' character. by @thejefflarson in #458
  * feat(cmd/push): parse requirements and deps from rulesfile by
    @alacuku in #467
  * update(cmd): bumped oras to v.2.4.0. by @FedeDP in #478
  * fix(registry/push): correctly remove temporary dir by @alacuku
    in #479
  * update(tests/push): add new tests for push command by @alacuku
    in #486
  * new: driver selection logic by @FedeDP in #484
  * new(pkg/driver): try to fetch kernel headers leveraging
    driverkit library when building drivers by @FedeDP in #476
  * chore(cmd,pkg,internal): switch to use oras-go credentials
    package since oras-go-credentials is deprecated by @FedeDP in
    [#496]
  * chore(cmd/push): uniform receiver for push command by @alacuku
    in #498
  * fix(pkg/driver): fixup kernel headers download by @FedeDP in
    [#499]
  * fix(artifact/info): filter out signature tags by @alacuku in
    [#507]
  * vote: docs(OWNERS): add alacuku (Aldo Lacuku) to approvers by
    @alacuku in #497
  * cleanup(cmd/driver): drop preview tag. by @FedeDP in #506
  * fix(install): fix missing dependency signature verification by
    @LucaGuerra in #509
  * chore(cmd): dropped leftover experimental for driver-loader. by
    @FedeDP in #515
  * fix: Add backend 'https' to default index by @QJoly in #520
  * chore(internal): old ebpf probe must have lowest priority. by
    @FedeDP in #521
  * fix(pkg/driver): avoid source of crash during distro Discovery.
    by @FedeDP in #530
  * chore(build): bump go version to 1.22 by @alacuku in #533
  * add new boolean arg for 'registry push' --add-floating-tags, it
    will auto add the tags for the major and the minor versions by
    @Issif in #543
  * cleanup(cmd,pkg): moved enum to its own package. by @FedeDP in
    [#550]
  * new(pkg): use driverkit local build processor instead of
    implementing drivers build by @FedeDP in #356
  * fix(pkg/driver): create envmap if nil since driverkit expects
    it. by @FedeDP in #551
  * chore(cmd/driver): remove redundant log. by @FedeDP in #552
  * chore: updated driverkit to v0.19.2 by @FedeDP in #553
  * chore(deps): Bump google.golang.org/api from 0.178.0 to 0.180.0
    by @dependabot in #559
  * chore(deps): Bump the gomod group with 3 updates by @dependabot
    in #558
  * feat: Add --platform option to artifact/install by @kpaulisse
    in #554
  * chore(deps): Bump the actions group with 2 updates by
    @dependabot in #556
  * chore(deps): Bump golangci/golangci-lint-action from 5.3.0
    to 6.0.1 by @dependabot in #557
  * feat: Add file backend to fetcher by @kpaulisse in #555
  * new(cmd/driver): driver config namespace from env variable by
    @FedeDP in #560
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.7.3:
  * fix(CI): add permissions to login-to-amazon-ecr job
  * new(ci): add provenance for main tag
  * fix(CI): properly get credentials for amazon ecr registry
  * new(CI): add provenance for ecr image
  * fix(ci): add permissions for AWS ecr
  * new(CI): add ecr repository
* Mon Feb 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.7.2:
  * bumped helper message
  * added http-header option in driver download
  * chore(pkg/driver): ubuntu has its own specific FixupKernel
    logic now.
  * fix(pkg/driver): fixed generic kernelversion fixup method.
  * pkg/driver/flatcar: Update the script
  * fix: Dead link in PR template
  * chore(cmd): fixed up some strings.
* Fri Feb  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package falcoctl: CLI for the Falco Cloud Native Runtime
  Security solution
